@@ -33,7 +33,17 @@ class Domoticz(IPlugin):
 #
 	def switchlight(self, jsonInput):
 		bodies = ""
+		if jsonInput['outcome']['entities']['location']['body'] :
+			location = jsonInput['outcome']['entities']['location']['body']
+		else:
+			bodies = "pas de lieu"
+			location= "VIDE"
 
+		if jsonInput['outcome']['entities']['on_off']['value'] :
+			on_off = jsonInput['outcome']['entities']['on_off']['value']
+		else:
+			bodies = "pas de on/off"
+			on_off = "VIDE"
 		idex= location + "_" + on_off
 		log.msg("index :  %s" % (idex))		
 		for rs in self.configuration_plugin['param_dz']:
@@ -57,7 +67,15 @@ class Domoticz(IPlugin):
 
 	def devices(self, jsonInput):
 		bodies = ""
-#			location = jsonInput['outcome']['entities']['location']['value']
+		if jsonInput['outcome']['entities']['location']['body'] :
+			location = jsonInput['outcome']['entities']['location']['body']
+		else:
+			bodies = "pas de lieu"
+			location= "VIDE"
+		if jsonInput['outcome']['entities']['local_search_query']['value'] :
+			local = jsonInput['outcome']['entities']['local_search_query']['value']
+		else:
+			bodies = "pas de local_search_query"
 #
 		idex= local + " " + location +  "_"
 		log.msg("index :  %s" % (idex))		
